@@ -1,5 +1,12 @@
 import datetime
+import six
+
+if six.PY3:
+    from io import IOBase as file
+
+
 from .base import InstanceResource, ListResource
+from .. import exceptions
 
 
 class CommentableResource(InstanceResource):
@@ -199,7 +206,8 @@ class Attachment(InstanceResource):
 
     allowed_params = [
         'object_id', 'project', 'attached_file',
-        'description', 'is_deprecated'
+        'description', 'is_deprecated', 'size',
+        'name', 'url'
     ]
 
 
@@ -218,8 +226,23 @@ class Attachments(ListResource):
         :param attrs: optional attributes for the :class:`Attachment`
         """
         attrs.update({'project': project, 'object_id': object_id})
+
+        if isinstance(attached_file, file):
+            attachment = attached_file
+        elif isinstance(attached_file, str):
+            try:
+                attachment = open(attached_file, 'rb')
+            except IOError:
+                raise exceptions.TaigaException(
+                    "Attachment must be a IOBase or a path to an existing file"
+                )
+        else:
+            raise exceptions.TaigaException(
+                "Attachment must be a IOBase or a path to an existing file"
+            )
+
         return self._new_resource(
-            files={'attached_file': open(attached_file, 'rb')},
+            files={'attached_file': attachment},
             payload=attrs
         )
 
@@ -248,7 +271,6 @@ class UserStory(CustomAttributeResource, CommentableResource):
     :param version: version of the :class:`UserStory`
     :param client_requirement: client requirement of the :class:`UserStory`
     :param description: description of the :class:`UserStory`
-    :param is_archived: is archived of the :class:`UserStory`
     :param is_blocked: is blocked of the :class:`UserStory`
     :param kanban_order: kanban order of the :class:`UserStory`
     :param milestone: milestone of the :class:`UserStory`
@@ -267,10 +289,9 @@ class UserStory(CustomAttributeResource, CommentableResource):
 
     allowed_params = [
         'assigned_to', 'backlog_order', 'blocked_note', 'version',
-        'client_requirement', 'description', 'is_archived', 'is_blocked',
-        'is_closed', 'kanban_order', 'milestone', 'points', 'project',
-        'sprint_order', 'status', 'subject', 'tags', 'team_requirement',
-        'watchers'
+        'client_requirement', 'description', 'is_blocked', 'is_closed',
+        'kanban_order', 'milestone', 'points', 'project', 'sprint_order',
+        'status', 'subject', 'tags', 'team_requirement', 'watchers'
     ]
 
     def add_task(self, subject, status, **attrs):
